# Changelog

## [6.0.1a1](https://github.com/OpenVoiceOS/ovos-workshop/tree/6.0.1a1) (2025-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-workshop/compare/6.0.0...6.0.1a1)

**Merged pull requests:**

- fix: dont require can\_stop if self.stop is not implemented [\#346](https://github.com/OpenVoiceOS/ovos-workshop/pull/346) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
